@@ -7,10 +7,8 @@ from typing import Any, Callable, Dict, Optional
 
 from google.protobuf.json_format import MessageToDict
 
-from flytekit.annotated.context_manager import SerializationSettings
-from flytekit.annotated.python_function_task import PythonFunctionTask
-from flytekit.annotated.resources import Resources
-from flytekit.annotated.task import TaskPlugins
+from flytekit import PythonFunctionTask, Resources
+from flytekit.extend import SerializationSettings, TaskPlugins
 from flytekit.models import task as _task_model
 
 
@@ -55,9 +53,7 @@ class TensorflowFunctionTask(PythonFunctionTask[TfJob]):
             task_type=self._TF_JOB_TASK_TYPE,
             task_config=task_config,
             task_function=task_function,
-            requests=task_config.per_replica_requests,
-            limits=task_config.per_replica_limits,
-            **kwargs
+            **{**kwargs, "requests": task_config.per_replica_requests, "limits": task_config.per_replica_limits}
         )
 
     def get_custom(self, settings: SerializationSettings) -> Dict[str, Any]:
